(* The package sedlex is released under the terms of an MIT-like license. *)
(* See the attached LICENSE file.                                         *)

open Sedlex_cset

(** Letters to be used in identifiers, as specified by ISO .... *)

(* Data provided by John M. Skaller *)

val tr8876_ident_char : t
